.. :changelog:

History
-------

0.4.0
++++++++++++++++++
* Fix modeling of form fields to handle non-unique field names.
* Allow selection of submit button if multiple submits are present.

0.1.0
++++++++++++++++++

* First release on PyPI.
